@@ -12,6 +12,7 @@ from .signal import Signal
 from binascii import b2a_hex
 import time
 import logging
+import socket
 
 
 # Constants
@@ -343,6 +344,7 @@ class BaseKISSDevice(object):
             self._open_time = time.time()
             self._state = KISSDeviceState.OPEN
             self._rx_buffer = bytearray()
+            return
 
         self._log.debug('Sending %r', command)
         command = command.encode('US-ASCII')
@@ -432,6 +434,38 @@ class SerialKISSDevice(BaseKISSDevice):
         self._serial.write(data)
 
 
+class TCPKISSDevice(BaseKISSDevice):
+
+    _interface = None
+    READ_BYTES = 1000
+
+    def __init__(self, host: str, port: int, *args, **kwargs):
+        super(TCPKISSDevice, self).__init__(*args, **kwargs)
+        self.address = (host, port)
+
+    def _open(self):
+        self._interface = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        self._interface.connect(self.address)
+        self._loop.add_reader(self._interface, self._on_recv_ready)
+        self._loop.call_soon(self._init_kiss)
+
+    def _on_recv_ready(self):
+        try:
+            read_data = self._interface.recv(self.READ_BYTES)
+            self._receive(read_data)
+        except:
+            self._log.exception('Failed to read from socket device')
+
+    def _send_raw_data(self, data):
+        self._interface.send(data)
+
+    def _close(self):
+        self._loop.remove_reader(self._interface)
+        self._interface.close()
+        self._interface = None
+        self._state = KISSDeviceState.CLOSED
+
+
 # Port interface
 
 
